##  Save Results
To quickly access your applications in scope later throughout the use case you can save this search.
  1. Click Save as in the top-right corner of the inventory.
  2. In the dialog that opens, enter an appropriate name, for example, “application rationalization” and click Save.
  3. To re-open the saved search, go to the Searches tab in the left panel. Click on the Saved search.
![Screenshot showing the configuration options like name and permission when saving a search](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiod4b4c34da2cc43fc9f04c56d232236f7_HiRes.png)
